#ifndef _DACT_H
#define _DACT_H
#define DACT_VER_MAJOR 0
#define DACT_VER_MINOR 3
#define DACT_VER_REVISION 21

#ifndef DACT_BLK_SIZE
#define DACT_BLK_SIZE 1024
#endif


#define DACT_MODE_COMPR 1
#define DACT_MODE_DECMP 2


#if defined(__WIN32__) || defined(GO32)
#ifndef TWO_BYTES
#define TWO_BYTES unsigned int
#endif
#ifndef FOUR_BYTES
#define FOUR_BYTES unsigned long
#endif
#undef USE_ZLIB
#else
#ifndef TWO_BYTES
#define TWO_BYTES unsigned short
#endif
#ifndef FOUR_BYTES
#define FOUR_BYTES unsigned int
#endif
#endif



struct dact_header {
/*
  This should be changed so it will work across BIG-LITTLE ENDIAN machines,
  if it does affect them.
*/
	TWO_BYTES	size;
	unsigned char	algo;
};
#endif
